<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'RecycleBin' => 'Papelera de Reciclaje',
'Recycle Bin' => 'Papelera de Reciclaje',
'MSG_EMPTY_RB_CONFIRMATION'=>'¿Estás seguro que quieres eliminar Permanentemente TODOS los registros borrados de la base de datos?',
'LBL_SELECT_MODULE'=>'Selecciona Módulo',
'LBL_EMPTY_MODULE'=>'No se han encontrado registros en el módulo para restaurar',
'LBL_MASS_RESTORE'=>'Restaurar',
'LBL_EMPTY_RECYCLEBIN'=>'Vaciar Papelera de Reciclaje',
'LNK_RESTORE'=>'restaurar',
'LBL_NO_PERMITTED_MODULES'=>'No hay modulos permitidos',
'LBL_MANUALRESTORE'=>'Recuperación manual antes de restaurar el registro',
'LBL_ALREADYEXISTS'=>'Ya existe en el CRM',
'LBL_AUTOMATICRESTORE'=>'Recuperación automática al restaurar el registro.',
);

?>